@@ -163,7 +163,7 @@ pub fn construct(packet: Vec<u8>) -> DnsPacket {
 			i = i + 1;
 			v = v - 1;
 		}
-		if zrtype == RecordType::TXT {
+		if fromtype(zrtype) == 16 {
 			data.remove(0 as usize);
 		}
 		let ans = DnsAnswer { name: 0xc00c, rtype: zrtype, class: class, ttl: ttl, data: data };
